@@ -62,12 +62,18 @@ public:
      * The title used to fill the window title template in formatted file names.
      */
     QString windowTitle() const;
+    void setWindowTitle(const QString &windowTitle);
 
     /**
      * Returns a formatted filename using a template string.
      */
     QString formattedFilename(const QString &nameTemplate = Settings::imageFilenameTemplate()) const;
 
+    /**
+     * The URL to use for an automatically named and saved file.
+     */
+    QUrl getAutosaveFilename() const;
+
     /**
      * The URL to record a video with before it is exported.
      */
@@ -75,6 +81,11 @@ public:
 
     const QTemporaryDir *temporaryDir();
 
+    /**
+     * Save a temporary screenshot file and return its URL.
+     */
+    QUrl tempSave();
+
     struct Placeholder {
         enum Flag {
             Other = 0,
@@ -112,22 +123,33 @@ public:
 
     static const QList<Placeholder> filenamePlaceholders;
 
+    /**
+     * Export an image with the given actions using the given URL or an automatically generated URL.
+     */
+    void exportImage(ExportManager::Actions actions, QUrl url = {});
+
+    /**
+     * Export an video with the given actions using the given URL or an automatically generated URL.
+     */
+    void exportVideo(ExportManager::Actions actions, const QUrl &inputUrl, QUrl outputUrl = {});
+
+    /**
+     * Scan the current image for a QR code.
+     */
+    void scanQRCode();
+
+    /**
+     * Print the current image with the given printer.
+     */
+    void doPrint(QPrinter *printer);
+
 Q_SIGNALS:
     void imageChanged();
 
     void errorMessage(const QString &str);
     void imageExported(const ExportManager::Actions &actions, const QUrl &url = {});
     void videoExported(const ExportManager::Actions &actions, const QUrl &url = {});
-
-public Q_SLOTS:
-
-    QUrl getAutosaveFilename() const;
-    QUrl tempSave();
-
-    void setWindowTitle(const QString &windowTitle);
-    void exportImage(ExportManager::Actions actions, QUrl url = {});
-    void exportVideo(ExportManager::Actions actions, const QUrl &inputUrl, QUrl outputUrl = {});
-    void doPrint(QPrinter *printer);
+    void qrCodeScanned(const QVariant &content);
 
 private:
     QString truncatedFilename(const QString &filename) const;
