@@ -9,7 +9,6 @@
 #include "Selection.h"
 #include "Geometry.h"
 #include "settings.h"
-#include "spectacle_gui_debug.h"
 
 #include <KLocalizedString>
 #include <KWindowSystem>
@@ -89,7 +88,9 @@ public:
 
     void setShowMagnifier(bool show)
     {
-        show = show && Settings::showMagnifier() && validMagnifierLocation(magnifierLocation);
+        show = (show || Settings::showMagnifier() == Settings::ShowMagnifierAlways) //
+            && Settings::showMagnifier() != Settings::ShowMagnifierNever //
+            && validMagnifierLocation(magnifierLocation);
         if (showMagnifier == show) {
             return;
         }
@@ -127,7 +128,7 @@ public:
     qreal devicePixelRatio = 1;
     qreal devicePixel = 1;
     QPointF mousePos;
-    bool showMagnifier = false;
+    bool showMagnifier = Settings::showMagnifier() == Settings::ShowMagnifierAlways;
     Location magnifierLocation = Location::FollowMouse;
     bool disableArrowKeys = false;
     QSet<Qt::Key> pressedKeys;
